@@ -120,7 +120,7 @@ class CrispyFieldNode(template.Node):
                 css_class = class_name
 
             if (
-                template_pack in ['bootstrap3']
+                template_pack == 'bootstrap3'
                 and not is_checkbox(field)
                 and not is_file(field)
                 and not is_multivalue(field)
@@ -130,7 +130,7 @@ class CrispyFieldNode(template.Node):
                     css_class += ' form-control-danger'
             
             if (
-                template_pack in ['bootstrap4']
+                template_pack == 'bootstrap4'
                 and not is_checkbox(field)
                 and not is_file(field)
                 and not is_multivalue(field)
