@@ -1,21 +1,20 @@
-import django
 from django import forms
 from django.db import models
 
 from crispy_forms.helper import FormHelper
 
 
-class TestForm(forms.Form):
+class SampleForm(forms.Form):
     is_company = forms.CharField(label="company", required=False, widget=forms.CheckboxInput())
     email = forms.EmailField(label="email", max_length=30, required=True, widget=forms.TextInput(), help_text="Insert your email")
     password1 = forms.CharField(label="password", max_length=30, required=True, widget=forms.PasswordInput())
     password2 = forms.CharField(label="re-enter password", max_length=30, required=True, widget=forms.PasswordInput())
     first_name = forms.CharField(label="first name", max_length=5, required=True, widget=forms.TextInput())
     last_name = forms.CharField(label="last name", max_length=5, required=True, widget=forms.TextInput())
-    datetime_field = forms.DateTimeField(label="date time", widget=forms.SplitDateTimeWidget())
+    datetime_field = forms.SplitDateTimeField(label="date time", widget=forms.SplitDateTimeWidget())
 
     def clean(self):
-        super(TestForm, self).clean()
+        super(SampleForm, self).clean()
         password1 = self.cleaned_data.get('password1', None)
         password2 = self.cleaned_data.get('password2', None)
         if not password1 and not password2 or password1 != password2:
@@ -24,13 +23,13 @@ class TestForm(forms.Form):
         return self.cleaned_data
 
 
-class TestForm2(TestForm):
+class SampleForm2(SampleForm):
     def __init__(self, *args, **kwargs):
-        super(TestForm2, self).__init__(*args, **kwargs)
+        super(SampleForm2, self).__init__(*args, **kwargs)
         self.helper = FormHelper(self)
 
 
-class CheckboxesTestForm(forms.Form):
+class CheckboxesSampleForm(forms.Form):
     checkboxes = forms.MultipleChoiceField(
         choices=(
             (1, "Option one"),
@@ -76,18 +75,18 @@ class CrispyTestModel(models.Model):
     password = models.CharField(max_length=20)
 
 
-class TestForm3(forms.ModelForm):
+class SampleForm3(forms.ModelForm):
     class Meta:
         model = CrispyTestModel
         fields = ['email', 'password']
         exclude = ['password']
 
     def __init__(self, *args, **kwargs):
-        super(TestForm3, self).__init__(*args, **kwargs)
+        super(SampleForm3, self).__init__(*args, **kwargs)
         self.helper = FormHelper(self)
 
 
-class TestForm4(forms.ModelForm):
+class SampleForm4(forms.ModelForm):
     class Meta:
         """
         before Django1.6, one cannot use __all__ shortcut for fields
@@ -96,11 +95,10 @@ class TestForm4(forms.ModelForm):
         because obviously it casts the string to a set
         """
         model = CrispyTestModel
-        if django.VERSION >= (1, 6):
-            fields = '__all__'  # eliminate RemovedInDjango18Warning
+        fields = '__all__'  # eliminate RemovedInDjango18Warning
 
 
-class TestForm5(forms.Form):
+class SampleForm5(forms.Form):
     choices = [
         (1, 1),
         (2, 2),
@@ -117,7 +115,35 @@ class TestForm5(forms.Form):
     pk = forms.IntegerField()
 
 
-class TestFormWithMedia(forms.Form):
+class SampleFormWithMedia(forms.Form):
     class Media:
         css = {'all': ('test.css',)}
         js = ('test.js',)
+
+
+class SampleFormWithMultiValueField(forms.Form):
+    multi = forms.SplitDateTimeField()
+
+class CrispyEmptyChoiceTestModel(models.Model):
+    fruit = models.CharField(
+        choices=[
+        ('apple','Apple'),
+        ('pear','Pear')],
+        null=True,
+        blank=True,
+    )
+
+class SampleForm6(forms.ModelForm):
+    class Meta:
+        """
+        When allowing null=True in a model field,
+        the corresponding field will have a choice
+        for the empty value.
+
+        When the form is initialized by an instance
+        with initial value None, this choice should
+        be selected.
+        """
+        model = CrispyEmptyChoiceTestModel
+        fields = ['fruit']
+        widgets = {'fruit': forms.RadioSelect() }
