@@ -1,17 +1,16 @@
 # -*- coding: utf-8 -*-
-from django import forms
-
 import pytest
 
-from .conftest import only_uni_form
+from django import forms
+
+from crispy_forms.bootstrap import AppendedText
 from crispy_forms.compatibility import string_types
 from crispy_forms.exceptions import DynamicError
 from crispy_forms.helper import FormHelper, FormHelpersException
-from crispy_forms.layout import (
-    Layout, Fieldset, MultiField, HTML, Div, Field
-)
-from crispy_forms.bootstrap import AppendedText
-from crispy_forms.tests.forms import TestForm
+from crispy_forms.layout import HTML, Div, Field, Fieldset, Layout, MultiField
+from crispy_forms.tests.forms import SampleForm
+
+from .conftest import only_uni_form
 
 
 def test_wrap_all_fields():
@@ -370,7 +369,7 @@ def test_layout_get_field_names():
 
 
 def test_filter_by_widget(advanced_layout):
-    form = TestForm()
+    form = SampleForm()
     form.helper = FormHelper(form)
     form.helper.layout = advanced_layout
     assert form.helper.filter_by_widget(forms.PasswordInput).slice == [
@@ -380,7 +379,7 @@ def test_filter_by_widget(advanced_layout):
 
 
 def test_exclude_by_widget(advanced_layout):
-    form = TestForm()
+    form = SampleForm()
     form.helper = FormHelper(form)
     form.helper.layout = advanced_layout
     assert form.helper.exclude_by_widget(forms.PasswordInput).slice == [
@@ -391,7 +390,7 @@ def test_exclude_by_widget(advanced_layout):
 
 
 def test_exclude_by_widget_and_wrap(advanced_layout):
-    form = TestForm()
+    form = SampleForm()
     form.helper = FormHelper(form)
     form.helper.layout = advanced_layout
     form.helper.exclude_by_widget(forms.PasswordInput).wrap(Field, css_class='hero')
@@ -406,14 +405,14 @@ def test_exclude_by_widget_and_wrap(advanced_layout):
 
 
 def test_all_without_layout():
-    form = TestForm()
+    form = SampleForm()
     form.helper = FormHelper()
     with pytest.raises(FormHelpersException):
         form.helper.all().wrap(Div)
 
 
 def test_filter_by_widget_without_form(advanced_layout):
-    form = TestForm()
+    form = SampleForm()
     form.helper = FormHelper()
     form.helper.layout = advanced_layout
     with pytest.raises(FormHelpersException):
